static const char* exop[] = {
	"MINTOKEN",
	"INTEGER",
	"UNSIGNED",
	"CHARACTER",
	"FLOATING",
	"STRING",
	"VOIDTYPE",
	"ADDRESS",
	"ARRAY",
	"BREAK",
	"CALL",
	"CASE",
	"CONSTANT",
	"CONTINUE",
	"DECLARE",
	"DEFAULT",
	"DYNAMIC",
	"ELSE",
	"EXIT",
	"FOR",
	"FUNCTION",
	"GSUB",
	"ITERATE",
	"ITERATER",
	"ID",
	"IF",
	"LABEL",
	"MEMBER",
	"NAME",
	"POS",
	"PRAGMA",
	"PRE",
	"PRINT",
	"PRINTF",
	"PROCEDURE",
	"QUERY",
	"RAND",
	"RETURN",
	"SCANF",
	"SPLIT",
	"SPRINTF",
	"SRAND",
	"SSCANF",
	"SUB",
	"SUBSTR",
	"SWITCH",
	"TOKENS",
	"UNSET",
	"WHILE",
	"F2I",
	"F2S",
	"I2F",
	"I2S",
	"S2B",
	"S2F",
	"S2I",
	"F2X",
	"I2X",
	"S2X",
	"X2F",
	"X2I",
	"X2S",
	"X2X",
	"XPRINT",
	"OR",
	"AND",
	"NE",
	"EQ",
	"GE",
	"LE",
	"RS",
	"LS",
	"IN_OP",
	"UNARY",
	"DEC",
	"INC",
	"CAST",
};
